Spec Details
============

Micro-decisions and implementation details.

.. toctree::
   :maxdepth: 1
   :caption: Core

   core/application
   core/server

.. toctree::
   :maxdepth: 1
   :caption: Request/Response

   request-response/request
   request-response/response
   request-response/datastructures

.. toctree::
   :maxdepth: 1
   :caption: Middleware

   middleware/chain
   middleware/authentication
   middleware/cors
   middleware/errors

.. toctree::
   :maxdepth: 1
   :caption: WebSocket

   websocket/websocket
   websocket/wsx-protocol

.. toctree::
   :maxdepth: 1
   :caption: Storage

   storage/storage
   storage/resources

.. toctree::
   :maxdepth: 1
   :caption: Applications

   applications/api-application
   applications/page-application
   applications/system-apps

.. toctree::
   :maxdepth: 1
   :caption: Executors

   executors/executor

.. toctree::
   :maxdepth: 1
   :caption: Dependencies

   dependencies/genro-routes
   dependencies/genro-toolbox
   dependencies/genro-tytx

.. toctree::
   :maxdepth: 1
   :caption: Future

   future/session
   future/spa-manager
   future/wsgi-migration
